/*
    Name............Chromatic Aberration
    Version.........1.1
    Description.....Separating RGB Channels.
    Support.........No support
    Author..........Scripting by xxJulexx / Referred to the parameter of tetsuo / Scripting template by Lian

*/


(function(){

    /*---------------------------------------------------------------------------------------------------------*/    
    function initGlobals(G) // scriptの名前とかエラーとか
    /*---------------------------------------------------------------------------------------------------------*/
    {                
        G.NAME                      =   "ChromaticAberration.jsx";
        G.TITLE                     =   "Chromatic Aberration";
        //-----------------------------------------------------------------------------------------------------
        G.NO_PROJ_ERR               =   {en:"Open a project first.", jp:"プロジェクトを開いて下さい."};
        G.NO_COMP_ERR               =   {en:"Select a composition.", jp:"コンポジションを選択して下さい."};
        G.NO_LAYER_ERR              =   {en:"Select at least one layer.", jp:"少なくとも1つのレイヤーを選択して下さい."};
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    function loc(str) // 言語(日本語or英語)
    /*---------------------------------------------------------------------------------------------------------*/
    {
        return app.language == Language.JAPANESE ? str["jp"] : str["en"];
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    function throwMsg(msg) // errorをalert
    /*---------------------------------------------------------------------------------------------------------*/
    {
        alert(loc(msg), G.TITLE);
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    function ChromaticAberration(comp)
    /*---------------------------------------------------------------------------------------------------------*/
    {       
		var activeLayer = comp.selectedLayers ; 
			
		// change blendmode and duplicate layer //
		activeLayer[0].blendingMode = BlendingMode.ADD;
		activeLayer[0].duplicate();
		activeLayer[0].duplicate();

		var index =activeLayer[0].index;

		// R Channel //
		comp.layer(index-2).name = "R Channel";
		comp.layer(index-2).property("Effects").addProperty("ADBE Channel Combiner").property(5).setValue(7);
		comp.layer(index-2).property("Effects").property("ADBE Channel Combiner").property(6).setValue(10);
		comp.layer(index-2).property("Effects").addProperty("ADBE Optics Compensation").property(1).setValue(10);

		// G Channel //
		comp.layer(index-1).name = "G Channel";
		comp.layer(index-1).property("Effects").addProperty("ADBE Channel Combiner").property(5).setValue(8);
		comp.layer(index-1).property("Effects").property("ADBE Channel Combiner").property(6).setValue(11);
		comp.layer(index-1).property("Effects").addProperty("ADBE Optics Compensation").property(1).setValue(30);

		// B Channel //
		comp.layer(index).name = "B Channel";
		comp.layer(index).property("Effects").addProperty("ADBE Channel Combiner").property(5).setValue(9);
		comp.layer(index).property("Effects").property("ADBE Channel Combiner").property(6).setValue(12);
		comp.layer(index).property("Effects").addProperty("ADBE Optics Compensation").property(1).setValue(40);
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    function main() 
    /*---------------------------------------------------------------------------------------------------------*/
    {
        // プロジェクトを開いているかチェック
        var proj = app.project;
        if (!proj) {
            throwMsg(G.NO_PROJ_ERR);
            return;
        }
        // コンポジションを選択してるかチェック
        var comp = proj.activeItem;
        if (!comp || !(comp instanceof CompItem)) {
            throwMsg(G.NO_COMP_ERR);
            return;
        }
        // レイヤーを選択する必要がある場合
        // レイヤーを少なくとも1つ選択してるかチェック
       if (comp.selectedLayers.length < 1){
           throwMsg(G.NO_LAYER_ERR);
           return;
       }
        
        // メイン処理であるtemplate()関数を実行
        app.beginUndoGroup(G.TITLE);
        ChromaticAberration(comp);
        app.endUndoGroup();
    }
    
    /*---------------------------------------------------------------------------------------------------------*/
    // Entry Point
    /*---------------------------------------------------------------------------------------------------------*/
    
    var G = new Object();
    initGlobals(G);
    main();

})();
